@@ -6,7 +6,7 @@ ROCS_DEFAULT_VALUES = dict(
     MAX_CONFS=200,
     EWINDOW=10,
     ROCS_OVERLAYS_DIR=None,
-    ROCS_OVERLAYS_PREFIX=None,
+    ROCS_OVERLAYS_PREFIX="",
     PROTEIN_NEG_VOL_FILE=None,
     LIGAND_NEG_VOL_FILE=None,
     ROCS_INPUT=None,
