@@ -43,9 +43,11 @@ class SASComponent(BaseScoreComponent):
 
     def _load_model(self, parameters: ComponentParameters):
         try:
-            activity_model = self._load_scikit_model(parameters.model_path)
+            model_path = self.parameters.specific_parameters.get(self.component_specific_parameters.MODEL_PATH, "")
+            activity_model = self._load_scikit_model(model_path)
         except:
-            raise Exception(f"The loaded file {parameters.model_path} isn't a valid scikit-learn model")
+            model_path = self.parameters.specific_parameters.get(self.component_specific_parameters.MODEL_PATH, "")
+            raise Exception(f"The loaded file `{model_path}` isn't a valid scikit-learn model")
         return activity_model
 
     def _load_scikit_model(self, model_path: str):
